//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[Hora](index.md)/[han](han.md)

# han

[common]\

@EncodeDefault

val [han](han.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

番
